package window.runtime {
	function trace(... arguments):void;
}

package window.runtime.flash.data {
	class EncryptedLocalStore {
		static function getItem(name:String):ByteArray;
		static function removeItem(name:String):void;
		static function reset():void;
		static function setItem(name:String, data:ByteArray, stronglyBound:Boolean=false):void;
	}
	
	class SQLCollationType {
		static const BINARY:String="binary";
		static const NO_CASE:String="noCase";
	}
	
	class SQLColumnNameStyle {
		static const DEFAULT:String="default";
		static const LONG:String="long";
		static const SHORT:String="short";
	}
	
	class SQLColumnSchema {
		const allowNull:Boolean;
		const autoIncrement:Boolean;
		const dataType:String;
		const defaultCollationType:String;
		const name:String;
		const primaryKey:Boolean;
		
		function SQLColumnSchema(name:String, primaryKey:Boolean, allowNull:Boolean, autoIncrement:Boolean, dataType:String, defaultCollationType:String);
	}
	
	class SQLConnection extends EventDispatcher {
		const autoCompact:Boolean;
		var cacheSize:uint;
		var columnNameStyle:String;
		const connected:Boolean;
		const inTransaction:Boolean;
		const lastInsertRowID:Number;
		const pageSize:uint;
		const totalChanges:Number;
		
		function SQLConnection();
		function addEventListener(type:String, listener:Function, useCapture:Boolean=false, priority:int=0, useWeakReference:Boolean=false):void
		function analyze(resourceName:String=null, responder:Responder=null):void;
		function attach(name:String, reference:Object=null, responder:Responder=null):void;
		function begin(option:String=null, responder:Responder=null):void;
		function cancel(responder:Responder=null):void;
		function close(responder:Responder=null):void;
		function commit(responder:Responder=null):void;
		function compact(responder:Responder=null):void;
		function deanalyze(responder:Responder=null):void;
		function detach(name:String, responder:Responder=null):void;
		function getSchemaResult():SQLSchemaResult;
		function loadSchema(type:Class=null, name:String=null, database:String="main", includeColumnSchema:Boolean=true, responder:Responder=null):void;
		function open(reference:Object=null, openMode:String="create", autoCompact:Boolean=false, pageSize:int=-1):void;
		function openAsync(reference:Object=null, openMode:String="create", responder:Responder=null, autoCompact:Boolean=false, pageSize:int=-1):void;
		function removeEventListener(type:String, listener:Function, useCapture:Boolean=false):void;
		function rollback(responder:Responder=null):void;
		
		/*@Event: analyze, attach, begin, cancel, close, commit, compact, deactivate, deanalyze, delete, detach, error, insert, open, rollback, schema, update */
	}
	
	class SQLIndexSchema extends SQLSchema {
		const table:String;
		
		function SQLIndexSchema(database:String, name:String, sql:String, table:String);
	}
	
	class SQLMode {
		static const CREATE:String="create";
		static const READ:String="read";
		static const UPDATE:String="update"
	}
	
	class SQLResult {
		const complete:Boolean;
		const data:Array;
		const lastInsertRowID:Number;
		const rowsAffected:Number;
		
		function SQLResult(data:Array=null, rowsAffected:Number=0, complete:Boolean=true, rowID:Number=0);
	}
	
	class SQLSchema {
		const database:String;
		const name:String;
		const sql:String;
		
		function SQLSchema(database:String, name:String, sql:String);
	}
	
	class SQLSchemaResult {
		const indices:SQLIndexSchema[];
		const tables:SQLTableSchema[];
		const triggers:SQLTriggerSchema[];
		const views:SQLViewSchema[];
		
		function SQLSchemaResult(tables:SQLTableSchema[], views:SQLViewSchema[], indices:SQLIndexSchema[], triggers:SQLTriggerSchema[]);
	}
	
	class SQLStatement extends EventDispatcher {
		const executing:Boolean;
		var itemClass:Class;
		const parameters:Object;
		var sqlConnection:SQLConnection;
		var text:String;

		function SQLStatement();
		function addEventListener(type:String, listener:Function, useCapture:Boolean=false, priority:int=0, useWeakReference:Boolean=false):void;
		function cancel():void;
		function clearParameters():void;
		function dispatchEvent(event:Event):Boolean;
		function execute(prefetch:int=-1, responder:Responder=null):void;
		function getResult():SQLResult;
		function hasEventListener(type:String):Boolean;
		function hasOwnProperty(name:String):Boolean;
		function isPrototypeOf(theClass:Object):Boolean;
		function next(prefetch:int=-1, responder:Responder=null):void;
		
		//@Event error, result
	}
	
	class SQLTableSchema extends SQLSchema {
		const columns:SQLColumnSchema[];
		
		function SQLTableSchema(database:String, name:String, sql:String, columns:SQLColumnSchema[]);
	}
	
	class SQLTransactionLockType {
		static const DEFERRED:String="deferred";
		static const EXCLUSIVE:String="exclusive";
		static const IMMEDIATE:String="immediate";
	}
	
	class SQLTriggerSchema extends SQLSchema {
		const table:String;
		
		function SQLTriggerSchema(database:String, name:String, sql:String, table:String);
	}
	
	class SQLViewSchema extends SQLTableSchema {
		function SQLViewSchema(database:String, name:String, sql:String, columns:SQLColumnSchema[]);
	}
}

package window.runtime.flash.desktop {
	class Clipboard {
		static const generalClipboard:Clipboard;
		
		const formats:String[];
		
		function Clipboard();
		function clear():void;
		function clearData(format:String):void;
		function getData(format:String, transferMode:String):Object;
		function hasFormat(format:String):Boolean;
		function setData(format:String, data:Object, serializable:Boolean=true):Boolean;
		function setDataHandler(format:String, handler:Function, serializable:Boolean=true):Boolean;
	}
	
	class ClipboardFormats {
		static const BITMAP_FORMAT:String="air:bitmap";
		static const FILE_LIST_FORMAT:String="air:file list";
		static const HTML_FORMAT:String="air:html";
		static const TEXT_FORMAT:String="air:text";
		static const URL_FORMAT:String="air:url";
	}
	
	class ClipboardTransferMode {
		static const CLONE_ONLY:String="cloneOnly";
		static const CLONE_PREFERRED:String="clonePreferred";
		static const ORIGINAL_ONLY:String="originalOnly";
		static const ORIGINAL_PREFERRED:String="originalPreferred";
	}
	
	class DockIcon extends InteractiveIcon {
		var menu:NativeMenu;
		
		function 	bounce(priority:String="informational"):void;
	}
	
	class InteractiveIcon extends Icon {
		const height:int;
		const width:int;
	}
	
	class Icon extends EventDispatcher {
		var bitmaps:BitmapData[];
	}
	
	class NativeApplication extends EventDispatcher {
		static const nativeApplication:NativeApplication;
		static const supportsDockIcon:Boolean;
		static const supportsMenu:Boolean;
		static const supportsSystemTrayIcon:Boolean;
		
		const activeWindow:NativeWindow;
		const applicationDescriptor:XML;
		const applicationID:String;
		const icon:InteractiveIcon;
		const openedWindows:NativeWindow[];
		const publisherID:String;
		const runtimePatchLevel:uint;
		const runtimeVersion:String;
		const timeSinceLastUserInput:int;
		
		var autoExit:Boolean;
		var idleThreshold:int;
		var menu:NativeMenu;
		var startAtLogin:Boolean;
		
		function activate(window:NativeWindow=null):void;
		function addEventListener(type:String, listener:Function, useCapture:Boolean=false, priority:int=0, useWeakReference:Boolean=false):void;
		function clear():Boolean;
		function copy():Boolean;
		function cut():Boolean;
		function dispatchEvent(event:Event):Boolean;
		function exit(errorCode:int=0):void;
		function getDefaultApplication(extension:String):String;
		function isSetAsDefaultApplication(extension:String):Boolean;
		function paste():Boolean;
		function redo():Boolean;
		function removeAsDefaultApplication(extension:String):void;
		function removeEventListener(type:String, listener:Function, useCapture:Boolean=false):void;
		function selectAll():Boolean;
		function setAsDefaultApplication(extension:String):void;
		function undo():Boolean;
		
		/*@Event activate, deactivate, exiting, invoke, networkChange, userIdle, userPresent */
	}
	
	class NativeDragActions {
		static const COPY:String="copy";
		static const LINK:String="link";
		static const MOVE:String="move";
		static const NONE:String="none"
	}
	
	class NativeDragManager {
		static const dragInitiator:InteractiveObject;
		static const 	isDragging:Boolean;
		
		static var dropAction:String;
		
		static function acceptDragDrop(target:InteractiveObject):void;
		static function doDrag(dragInitiator:InteractiveObject, clipboard:Clipboard, dragImage:BitmapData=null, offset:Point=null, allowedActions:NativeDragOptions=null):void;
	}
	
	class NativeDragOptions {
		var allowCopy:Boolean=true;
		var allowLink:Boolean=true;
		var allowMove:Boolean=true;
	}
	
	class NotificationType {
		static const CRITICAL:String="critical";
		static const INFORMATIONAL:String="informational";
	}
	
	class SystemTrayIcon extends InteractiveIcon {
		static const MAX_TIP_LENGTH:Number=63;
		
		var menu:NativeMenu;
		var tooltip:String;
		/*@Event click, mouseDown, mouseUp, rightClick, rightMouseDown, rightMouseUp */
	}
	
	class Updater {
		function Updater();
		function update(airFile:File, version:String):void;
	}
}

package window.runtime.flash.display {
	/*
	class Bitmap {
		var bitmapData:BitmapData;
		var pixelSnapping:String;
		var smoothing:Boolean;
		
		function Bitmap(bitmapData:BitmapData=null, pixelSnapping:String="auto", smoothing:Boolean=false);
	}
	*/
	class BitmapData {
		const height:int;
		const rect:Rectangle;
		const transparent:Boolean;
		const width:int;
		
		function BitmapData(width:int, height:int, transparent:Boolean=true, fillColor:uint=0xFFFFFFFF);
		function applyFilter(sourceBitmapData:BitmapData, sourceRect:Rectangle, destPoint:Point, filter:BitmapFilter):void;
		function clone():BitmapData;
		function colorTransform(rect:Rectangle, colorTransform:ColorTransform):void;
		function compare(otherBitmapData:BitmapData):Object;
		function copyChannel(sourceBitmapData:BitmapData, sourceRect:Rectangle, destPoint:Point, sourceChannel:uint, destChannel:uint):void;
		function copyPixels(sourceBitmapData:BitmapData, sourceRect:Rectangle, destPoint:Point, alphaBitmapData:BitmapData=null, alphaPoint:Point=null, mergeAlpha:Boolean=false):void;
		function dispose():void;
		function draw(source:IBitmapDrawable, matrix:Matrix=null, colorTransform:ColorTransform=null, blendMode:String=null, clipRect:Rectangle=null, smoothing:Boolean=false):void;
		function fillRect(rect:Rectangle, color:uint):void;
		function floodFill(x:int, y:int, color:uint):void;
		function generateFilterRect(sourceRect:Rectangle, filter:BitmapFilter):Rectangle;
		function getColorBoundsRect(mask:uint, color:uint, findColor:Boolean=true):Rectangle;
		function getPixel(x:int, y:int):uint;
		function getPixel32(x:int, y:int):uint;
		function getPixels(rect:Rectangle):ByteArray;
		function hitTest(firstPoint:Point, firstAlphaThreshold:uint, secondObject:Object, secondBitmapDataPoint:Point=null, secondAlphaThreshold:uint=1):Boolean;
		function lock():void;
		function merge(sourceBitmapData:BitmapData, sourceRect:Rectangle, destPoint:Point, redMultiplier:uint, greenMultiplier:uint, blueMultiplier:uint, alphaMultiplier:uint):void;
		function noise(randomSeed:int, low:uint=0, high:uint=255, channelOptions:uint=7, grayScale:Boolean=false):void;
		function paletteMap(sourceBitmapData:BitmapData, sourceRect:Rectangle, destPoint:Point, redArray:Array=null, greenArray:Array=null, blueArray:Array=null, alphaArray:Array=null):void;
		function perlinNoise(baseX:Number, baseY:Number, numOctaves:uint, randomSeed:int, stitch:Boolean, fractalNoise:Boolean, channelOptions:uint=7, grayScale:Boolean=false, offsets:Point[]=null):void;
		function pixelDissolve(sourceBitmapData:BitmapData, sourceRect:Rectangle, destPoint:Point, randomSeed:int=0, numPixels:int=0, fillColor:uint=0):int;
		function scroll(x:int, y:int):void;
		function setPixel(x:int, y:int, color:uint):void;
		function setPixel32(x:int, y:int, color:uint):void;
		function setPixels(rect:Rectangle, inputByteArray:ByteArray):void;
		function threshold(sourceBitmapData:BitmapData, sourceRect:Rectangle, destPoint:Point, operation:String, threshold:uint, color:uint=0, mask:uint=0xFFFFFFFF, copySource:Boolean=false):uint;
		function unlock(changeRect:Rectangle=null):void;
	}
	
	class NativeMenu extends EventDispatcher {
		const items:NativeMenuItem[];
		const numItems:int;
		const parent:NativeMenu;
		
		function addItem(item:NativeMenuItem):NativeMenuItem;
		function addItemAt(item:NativeMenuItem, index:int):NativeMenuItem;
		function addSubmenu(submenu:NativeMenu, label:String):NativeMenuItem;
		function addSubmenuAt(submenu:NativeMenu, index:int, label:String):NativeMenuItem;
		function clone():NativeMenu;
		function containsItem(item:NativeMenuItem):Boolean;
		function display(stage:Stage, stageX:Number, stageY:Number):void;
		function getItemAt(index:int):NativeMenuItem;
		function getItemByName(name:String):NativeMenuItem;
		function getItemIndex(item:NativeMenuItem):int;
		function removeItem(item:NativeMenuItem):NativeMenuItem;
		function removeItemAt(index:int):NativeMenuItem;
		function setItemIndex(item:NativeMenuItem, index:int):void;
		
		/*@Event displaying, select */
	}
	
	class NativeMenuItem extends EventDispatcher {
		var checked:Boolean;
		var data:Object;
		var enabled:Boolean;
		const isSeparator:Boolean;
		var keyEquivalent:String;
		var keyEquivalentModifiers:uint[];
		var label:String;
		const menu:NativeMenu;
		var mnemonicIndex:int;
		var name:String;
		var submenu:NativeMenu;
		
		function NativeMenuItem(label:String="", isSeparator:Boolean=false);
		function clone():NativeMenuItem;
		
		/*@Event displaying, select */
	}
	
	class Screen extends EventDispatcher {
		static const mainScreen:Screen;
		static const screens:Screen[];
		
		const bounds:Rectangle;
		const colorDepth:int;
		const visibleBounds:Rectangle;
		
		static function getScreensForRectangle(rect:Rectangle):Screen[];
	}
	
	class NativeWindow extends EventDispatcher {
		static const supportsMenu:Boolean;
		static const supportsNotification:Boolean;
		static const systemMaxSize:Point;
		static const systemMinSize:Point;
		
		const active:Boolean;
		const closed:Boolean;
		const displayState:String;
		const maximizable:Boolean;
		const minimizable:Boolean;
		const resizable:Boolean;
		const stage:Stage;
		const systemChrome:String;
		const transparent:Boolean;
		const type:String;
		
		var alwaysInFront:Boolean;
		var bounds:Rectangle;
		var height:Number;
		var maxSize:Point;
		var menu:NativeMenu;
		var minSize:Point;
		var title:String;
		var visible:Boolean;
		var width:Number;
		var x:Number;
		var y:Number;
		
		function NativeWindow(initOptions:NativeWindowInitOptions);
		function activate():void;
		function close():void;
		function globalToScreen(globalPoint:Point):Point;
		function maximize():void;
		function minimize():void;
		function notifyUser(type:String):void;
		function orderInBackOf(window:NativeWindow):Boolean;
		function orderInFrontOf(window:NativeWindow):Boolean;
		function orderToBack():Boolean;
		function orderToFront():Boolean;
		function restore():void;
		function startMove():Boolean;
		function startResize(edgeOrCorner:String):Boolean;
		
		/*@Event activate, close, closing, deactivate, displayStateChange, displayStateChanging, move, moving, resize, resizing */
	}
	
	class NativeWindowType {
		static const LIGHTWEIGHT : String = "lightweight";
		static const NORMAL : String = "normal";
		static const UTILITY : String = "utility"
	}
	
	class NativeWindowDisplayState {
		static const MAXIMIZED:String="maximized";
		static const MINIMIZED:String="minimized";
		static const NORMAL:String="normal";
	}
	
	class NativeWindowInitOptions {
		var maximizable:Boolean;
		var minimizable:Boolean;
		var resizable:Boolean;
		var systemChrome:String;
		var transparent:Boolean;
		var type:String;
		
		function NativeWindowInitOptions();
	}
	
	class NativeWindowResize {
		static const BOTTOM:String="B";
		static const BOTTOM_LEFT:String="BL";
		static const BOTTOM_RIGHT:String="BR";
		static const LEFT:String="L";
		static const NONE:String="";
		static const RIGHT:String="R";
		static const TOP:String="T";
		static const TOP_LEFT:String="TL";
		static const TOP_RIGHT:String="TR";
	}
	
	class NativeWindowSystemChrome {
		static const NONE:String="none";
		static const STANDARD:String="standard";
	}
}

package window.runtime.flash.events {
	class Event {
		static const ACTIVATE:String="activate";
		static const ADDED:String="added";
		static const ADDED_TO_STAGE:String="addedToStage";
		static const CANCEL:String="cancel";
		static const CHANGE:String="change";
		static const CLOSE:String="close";
		static const CLOSING:String="closing";
		static const COMPLETE:String="complete";
		static const CONNECT:String="connect";
		static const DEACTIVATE:String="deactivate";
		static const DISPLAYING:String="displaying";
		static const ENTER_FRAME:String="enterFrame";
		static const EXITING:String="exiting";
		static const FULLSCREEN:String="fullScreen";
		static const HTML_BOUNDS_CHANGE:String="htmlBoundsChange";
		static const HTML_DOM_INITIALIZE:String="htmlDOMInitialize";
		static const HTML_RENDER:String="htmlRender";
		static const ID3:String="id3";
		static const INIT:String="init";
		static const LOCATION_CHANGE:String="locationChange";
		static const MOUSE_LEAVE:String="mouseLeave";
		static const NETWORK_CHANGE:String="networkChange";
		static const OPEN:String="open";
		static const REMOVED:String="removed";
		static const REMOVED_FROM_STAGE:String="removedFromStage";
		static const RENDER:String="render";
		static const RESIZE:String="resize";
		static const SCROLL:String="scroll";
		static const SELECT:String="select";
		static const SOUND_COMPLETE:String="soundComplete";
		static const TAB_CHILDREN_CHANGE:String="tabChildrenChange";
		static const TAB_ENABLED_CHANGE:String="tabEnabledChange";
		static const TAB_INDEX_CHANGE:String="tabIndexChange";
		static const UNLOAD:String="unload";
		static const USER_IDLE:String="userIdle";
		static const USER_PRESENT:String="userPresent";
		
		const bubbles:Boolean;
		const cancelable:Boolean;
		const currentTarget:Object;
		const eventPhase:uint;
		const target:Object;
		const type:String;
		
		function Event(type:String, bubbles:Boolean=false, cancelable:Boolean=false);
		function clone():Event ;
		function formatToString(className:String, ... arguments):String;
		function isDefaultPrevented():Boolean;
		function preventDefault():void;
		function stopImmediatePropagation():void;
		function stopPropagation():void;
		function toString():String;
	}
	
	class NativeWindowBoundsEvent extends Event {
		static const MOVE:String="move";
		static const MOVING:String="moving";
		static const RESIZE:String="resize";
		static const RESIZING:String="resizing";

		const afterBounds:Rectangle;
		const beforeBounds:Rectangle;
		
		function NativeWindowBoundsEvent(type:String, bubbles:Boolean=false, cancelable:Boolean=false, beforeBounds:Rectangle=null, afterBounds:Rectangle=null);
		function clone():Event;
	}
	
	class NativeWindowDisplayStateEvent extends Event {
		static const DISPLAY_STATE_CHANGE:String="displayStateChange";
		static const DISPLAY_STATE_CHANGING:String="displayStateChanging";
		
		const afterDisplayState:String;
		const beforeDisplayState:String;
		
		function NativeWindowDisplayStateEvent(type:String, bubbles:Boolean=true, cancelable:Boolean=false, beforeDisplayState:String="", afterDisplayState:String="");
		function clone():Event;
	}
	
	class EventDispatcher {
		function EventDispatcher(target:IEventDispatcher=null);
		function addEventListener(type:String, listener:Function, useCapture:Boolean=false, priority:int=0, useWeakReference:Boolean=false):void;
		function dispatchEvent(event:Event):Boolean;
		function hasEventListener(type:String):Boolean;
		function removeEventListener(type:String, listener:Function, useCapture:Boolean=false):void;
		function willTrigger(type:String):Boolean;
		
		/*@Event: activate,  deactivate */
	}
	
	class ActivityEvent extends Event {
		static const ACTIVITY:String="activity";
		
		var activating:Boolean;
		
		function ActivityEvent(type:String, bubbles:Boolean=false, cancelable:Boolean=false, activating:Boolean=false);
		function clone():Event;
	}
	
	class AsyncErrorEvent extends Event {
		static const ASYNC_ERROR:String="asyncError";
		
		var error:Error;
		
		function AsyncErrorEvent(type:String, bubbles:Boolean=false, cancelable:Boolean=false, text:String="", error:Error=null);
		function clone():Event
	}
	
	class DRMAuthenticateEvent extends Event {
		static const AUTHENTICATION_TYPE_DRM:String="drm";
		static const AUTHENTICATION_TYPE_PROXY:String="proxy";
		static const DRM_AUTHENTICATE:String="drmAuthenticate";
		
		var authenticationType:String;
		var header:String;
		var netstream:NetStream;
		var passwordPrompt:String;
		var urlPrompt:String;
		var usernamePrompt:String;
		
		function DRMAuthenticateEvent(type:String, bubbles:Boolean=false, cancelable:Boolean=false, header:String="", userPrompt:String="", passPrompt:String="", urlPrompt:String="", authenticationType:String="", netstream:NetStream=null);
		function clone():Event;
	}
	
	class DRMStatusEvent extends Event {
		static const DRM_STATUS:String="drmStatus";
		
		const detail:String;
		const isAnonymous:Boolean;
		const isAvailableOffline:Boolean;
		const offlineLeasePeriod:uint;
		const policies:Object;
		const voucherEndDate:Date;
		
		function DRMStatusEvent(type:String, bubbles:Boolean=false, cancelable:Boolean=false, inPolicies:Object=null, inDetail:String="", inAvailableOffline:Boolean=false, inAnonymous:Boolean=false, inVoucherEndDate:int=0, inOfflineLeasePeriod:int=0);
		function clone():Event;
	}
	
	class DataEvent extends Event {
		static const DATA:String="data";
		static const UPLOAD_COMPLETE_DATA:String="uploadCompleteData";
		
		var data:String;
		
		function DataEvent(type:String, bubbles:Boolean=false, cancelable:Boolean=false, data:String="");
		function clone():Event;
	}
	
	class FileListEvent extends Event {
		static const DIRECTORY_LISTING:String="directoryListing";
		static const SELECT_MULTIPLE:String="selectMultiple";
		
		var files:File[];
		
		function FileListEvent(type:String, bubbles:Boolean=false, cancelable:Boolean=false, files:File[]=null);
	}
	
	class HTTPStatusEvent extends Event {
		static const HTTP_RESPONSE_STATUS:String="httpResponseStatus";
		static const HTTP_STATUS:String="httpStatus";
		
		var responseHeaders:URLRequestHeader[];
		var responseURL:String;
		const status:int;
		
		function HTTPStatusEvent(type:String, bubbles:Boolean=false, cancelable:Boolean=false, status:int=0);
		function clone():Event;
	}
	
	class SQLErrorEvent extends /*ErrorEvent*/Event {
		static const ERROR:String="error";
		
		const error:SQLError ;
		
		function SQLErrorEvent(type:String, bubbles:Boolean=false, cancelable:Boolean=false, error:SQLError=null);
		function clone():Event ;
		function toString():String;
	}
	
	class IOErrorEvent extends Event {
		static const IO_ERROR:String="ioError";
		
		function IOErrorEvent(type:String, bubbles:Boolean=false, cancelable:Boolean=false, text:String="", id:int=0);
		function clone():Event;
	}
	
	class InvokeEvent extends Event {
		static const INVOKE:String="invoke";
		
		const arguments:String[];
		const currentDirectory:File;
		
		function InvokeEvent(type:String, bubbles:Boolean=false, cancelable:Boolean=false, dir:File=null, argv:String[]=null);
		function clone():Event;
	}
	
	class KeyboardEvent extends Event {
		static const KEY_DOWN:String="keyDown";
		static const KEY_UP:String="keyUp";
		
		var altKey:Boolean;
		var charCode:uint;
		var commandKey:Boolean;
		var controlKey:Boolean;
		var ctrlKey:Boolean;
		var keyCode:uint;
		var keyLocation:uint;
		var shiftKey:Boolean;
		
		function KeyboardEvent(type:String, bubbles:Boolean=true, cancelable:Boolean=false, charCodeValue:uint=0, keyCodeValue:uint=0, keyLocationValue:uint=0, ctrlKeyValue:Boolean=false, altKeyValue:Boolean=false, shiftKeyValue:Boolean=false, controlKeyValue:Boolean=false, commandKeyValue:Boolean=false);
		function clone():Event;
		function updateAfterEvent():void;
	}
	
	class SQLEvent extends Event {
		static const ANALYZE:String="analyze";
		static const ATTACH:String="attach";
		static const BEGIN:String="begin";
		static const CANCEL:String="cancel";
		static const CLOSE:String="close";
		static const COMMIT:String="commit";
		static const COMPACT:String="compact";
		static const DEANALYZE:String="deanalyze";
		static const DETACH:String="detach";
		static const OPEN:String="open";
		static const RESULT:String="result";
		static const ROLLBACK:String="rollback";
		static const SCHEMA:String="schema";
		
		function SQLEvent(type:String, bubbles:Boolean=false, cancelable:Boolean=false);
		function clone():Event;
	}
	
	class MouseEvent extends Event {
		static const CLICK:String="click";
		static const CONTEXT_MENU:String="contextMenu";
		static const DOUBLE_CLICK:String="doubleClick";
		static const MIDDLE_CLICK:String="middleClick";
		static const MIDDLE_MOUSE_DOWN:String="middleMouseDown";
		static const MIDDLE_MOUSE_UP:String="middleMouseUp";
		static const MOUSE_DOWN:String="mouseDown";
		static const MOUSE_MOVE:String="mouseMove";
		static const MOUSE_OUT:String="mouseOut";
		static const MOUSE_OVER:String="mouseOver";
		static const MOUSE_UP:String="mouseUp";
		static const MOUSE_WHEEL:String="mouseWheel";
		static const RIGHT_CLICK:String="rightClick";
		static const RIGHT_MOUSE_DOWN:String="rightMouseDown";
		static const RIGHT_MOUSE_UP:String="rightMouseUp";
		static const ROLL_OUT:String="rollOut";
		static const ROLL_OVER:String="rollOver";

		const clickCount:int;
		const stageX:Number;
		const stageY:Number;
		
		var altKey:Boolean;
		var buttonDown:Boolean;
		var commandKey:Boolean;
		var controlKey:Boolean;
		var ctrlKey:Boolean;
		var delta:int;
		var localX:Number;
		var localY:Number;
		var relatedObject:InteractiveObject;
		var shiftKey:Boolean;
		
		function MouseEvent(type:String, bubbles:Boolean=true, cancelable:Boolean=false, localX:Number, localY:Number, relatedObject:InteractiveObject=null, ctrlKey:Boolean=false, altKey:Boolean=false, shiftKey:Boolean=false, buttonDown:Boolean=false, delta:int=0, commandKey:Boolean=false, controlKey:Boolean=false, clickCount:int=0);
		function clone():Event;
		function updateAfterEvent():void;
	}
	
	class NativeDragEvent extends MouseEvent {
		static const NATIVE_DRAG_COMPLETE:String="nativeDragComplete";
		static const NATIVE_DRAG_DROP:String="nativeDragDrop";
		static const NATIVE_DRAG_ENTER:String="nativeDragEnter";
		static const NATIVE_DRAG_EXIT:String="nativeDragExit";
		static const NATIVE_DRAG_OVER:String="nativeDragOver";
		static const NATIVE_DRAG_START:String="nativeDragStart";
		static const NATIVE_DRAG_UPDATE:String="nativeDragUpdate";
		
		var allowedActions:NativeDragOptions;
		var clipboard:Clipboard;
		var dropAction:String;
		
		function NativeDragEvent(type:String, bubbles:Boolean=false, cancelable:Boolean=true, localX:Number, localY:Number, relatedObject:InteractiveObject=null, clipboard:Clipboard=null, allowedActions:NativeDragOptions=null, dropAction:String=null, controlKey:Boolean=false, altKey:Boolean=false, shiftKey:Boolean=false, commandKey:Boolean=false);
		function clone():Event;
	}
	
	class NetStatusEvent extends Event {
		static const NET_STATUS:String="netStatus";
		
		var info:Object;
		
		function NetStatusEvent(type:String, bubbles:Boolean=false, cancelable:Boolean=false, info:Object=null);
		function clone():Event;
	}
	
	class OutputProgressEvent extends Event {
		static const OUTPUT_PROGRESS:String="outputProgress";
		
		var bytesPending:Number;
		var bytesTotal:Number;
		
		function OutputProgressEvent(type:String, bubbles:Boolean=false, cancelable:Boolean=false, bytesPending:Number=0, bytesTotal:Number=0);
		function clone():Event;
	}
	
	class ProgressEvent extends Event {
		static const PROGRESS:String="progress";
		static const SOCKET_DATA:String="socketData";
		
		var bytesLoaded:Number;
		var bytesTotal:Number;
		
		function ProgressEvent(type:String, bubbles:Boolean=false, cancelable:Boolean=false, bytesLoaded:Number=0, bytesTotal:Number=0);
		function clone():Event;
	}
	
	class SecurityErrorEvent extends Event {
		static const SECURITY_ERROR:String="securityError";
		
		function SecurityErrorEvent(type:String, bubbles:Boolean=false, cancelable:Boolean=false, text:String="", id:int=0);
		function clone():Event;
	}
	
	class SQLUpdateEvent extends Event {
		static const DELETE:String="delete";
		static const INSERT:String="insert";
		static const UPDATE:String="update"
		
		const rowID:Number;
		const table:String;
		
		function SQLUpdateEvent(type:String, bubbles:Boolean=false, cancelable:Boolean=false, table:String=null, rowID:Number=0);
		function clone():Event;
	}
	
	class StatusEvent extends Event {
		static const STATUS:String="status";
		
		var code:String;
		var level:String;
		
		function StatusEvent(type:String, bubbles:Boolean=false, cancelable:Boolean=false, code:String="", level:String="");
		function clone():Event;
	}
	
	class TimerEvent extends Event {
		static const TIMER:String="timer";
		static const TIMER_COMPLETE:String="timerComplete";
		
		function TimerEvent(type:String, bubbles:Boolean=false, cancelable:Boolean=false);
		function clone():Event;
		function updateAfterEvent():void;
	}
}

package window.runtime.flash.errors {
	class SQLError extends Error {
		const details:String;
		const operation:String;
		
		function SQLError(operation:String, details:String="", message:String="", id:int=0);
		function toString():String;
	}
	
	class SQLErrorOperation {
		static const ANALYZE:String="analyze";
		static const ATTACH:String="attach";
		static const BEGIN:String="begin";
		static const CLOSE:String="close";
		static const COMMIT:String="commit";
		static const COMPACT:String="compact";
		static const DEANALYZE:String="deanalyze";
		static const DETACH:String="detach";
		static const EXECUTE:String="execute";
		static const OPEN:String="open";
		static const ROLLBACK:String="rollback";
		static const SCHEMA:String="schema";
	}
}

package window.runtime.flash.filesystem {
	class File extends EventDispatcher {
		static const applicationDirectory:File;
		static const applicationStorageDirectory:File;
		static const desktopDirectory:File;
		static const documentsDirectory:File;
		static const lineEnding:String;
		static const separator:String;
		static const systemCharset:String;
		static const userDirectory:File;

		const exists:Boolean;
		const icon:Icon;
		const isDirectory:Boolean;
		const isHidden:Boolean;
		const isPackage:Boolean;
		const isSymbolicLink:Boolean;
		const parent:File;
		
		var nativePath:String;
		var url:String;

		static function createTempDirectory():File;
		static function createTempFile():File;
		static function getRootDirectories():File[];
		
		function File(path:String=null);
		function browseForDirectory(title:String):void;
		function browseForOpen(title:String, typeFilter:FileFilter[]=null):void;
		function browseForOpenMultiple(title:String, typeFilter:FileFilter[]=null):void;
		function browseForSave(title:String):void;
		function cancel():void;
		function canonicalize():void;
		function clone():File;
		function copyTo(newLocation:FileReference, overwrite:Boolean=false):void;
		function copyToAsync(newLocation:FileReference, overwrite:Boolean=false):void;
		function createDirectory():void;
		function deleteDirectory(deleteDirectoryContents:Boolean=false):void;
		function deleteDirectoryAsync(deleteDirectoryContents:Boolean=false):void;
		function deleteFile():void;
		function deleteFileAsync():void;
		function getDirectoryListing():File[];
		function getDirectoryListingAsync():void;
		function getRelativePath(ref:FileReference, useDotDot:Boolean=false):String;
		function moveTo(newLocation:FileReference, overwrite:Boolean=false):void;
		function moveToAsync(newLocation:FileReference, overwrite:Boolean=false):void;
		function moveToTrash():void;
		function moveToTrashAsync():void;
		function resolvePath(path:String):File;
		
		/*@Event: cancel, complete, directoryListing, ioError, securityError, select, selectMultiple */
	}
	
	class FileMode {
		static const APPEND:String="append";
		static const READ:String="read";
		static const UPDATE:String="update";
		static const WRITE:String="write";
	}
	
	class FileStream extends EventDispatcher {
		const bytesAvailable:uint;
		
		var endian:String;
		var objectEncoding:uint;
		var position:Number;
		var readAhead:Number;
		
		function FileStream();
		function close():void;
		function open(file:File, fileMode:String):void;
		function openAsync(file:File, fileMode:String):void;
		function readBoolean():Boolean;
		function readByte():int;
		function readBytes(bytes:ByteArray, offset:uint=0, length:uint=0):void;
		function readDouble():Number;
		function readFloat():Number;
		function readInt():int;
		function readMultiByte(length:uint, charSet:String):String;
		function readObject():*;
		function readShort():int;
		function readUnsignedByte():uint;
		function readUnsignedInt():uint;
		function readUnsignedShort():uint;
		function readUTF():String;
		function readUTFBytes(length:uint):String;
		function truncate():void;
		function writeBoolean(value:Boolean):void;
		function writeByte(value:int):void;
		function writeBytes(bytes:ByteArray, offset:uint=0, length:uint=0):void;
		function writeDouble(value:Number):void;
		function writeFloat(value:Number):void;
		function writeInt(value:int):void;
		function writeMultiByte(value:String, charSet:String):void;
		function writeObject(object:*):void;
		function writeShort(value:int):void;
		function writeUnsignedInt(value:uint):void;
		function writeUTF(value:String):void;
		function writeUTFBytes(value:String):void;
		
		/*@Event: close complete ioError outputProgress progress */
	}
}

package window.runtime.flash.html {
	class HTMLLoader extends EventDispatcher {
		static const pdfCapability:int;
		
		const contentHeight:Number;
		const contentWidth:Number;
		const hasFocusableContent:Boolean;
		const historyLength:uint;
		const loaded:Boolean;
		const location:String;
		const window:Object;
		
		var authenticate:Boolean;
		var cacheResponse:Boolean;
		var height:Number;
		var historyPosition:uint;
		var htmlHost:HTMLHost;
		var manageCookies:Boolean;
		var navigateInSystemBrowser:Boolean;
		var paintsDefaultBackground:Boolean;
		var runtimeApplicationDomain:ApplicationDomain;
		var scrollH:Number;
		var scrollV:Number;
		var textEncodingFallback:String;
		var textEncodingOverride:String;
		var useCache:Boolean;
		var userAgent:String;
		var width:Number;
		
		static function createRootWindow(visible:Boolean=true, windowInitOptions:NativeWindowInitOptions=null, scrollBarsVisible:Boolean=true, bounds:Rectangle=null):HTMLLoader;
		
		function HTMLLoader();
		function cancelLoad():void;
		function getHistoryAt(position:uint):HTMLHistoryItem;
		function historyBack():void;
		function historyForward():void;
		function historyGo(steps:int):void;
		function load(urlRequestToLoad:URLRequest):void;
		function loadString(htmlContent:String):void;
		function reload():void;
		
		/*@Event complete htmlBoundsChange htmlDOMInitialize htmlRender locationChange scroll uncaughtScriptException */
	}
}

package window.runtime.flash.net {
	function navigateToURL(request:URLRequest, window:String):void;
	function sendToURL(request:URLRequest):void;
	
	class FileFilter {
		var description:String;
		var extension:String;
		var macType:String;
		
		function FileFilter(description:String, extension:String, macType:String=null);
	}
	
	class LocalConnection extends EventDispatcher {
		const domain:String;
		
		var client:Object;
		
		function LocalConnection();
		function allowDomain(... domains):void;
		function allowInsecureDomain(... domains):void;
		function close():void;
		function connect(connectionName:String):void;
		function send(connectionName:String, methodName:String, ... arguments):void;
		
		/*@Event asyncError, securityError, status */
	}
	
	class NetConnection extends EventDispatcher {
		static var defaultObjectEncoding:uint;
		
		const connected:Boolean;
		const connectedProxyType:String;
		const uri:String;
		const usingTLS:Boolean;
		
		var client:Object;
		var objectEncoding:uint;
		var proxyType:String;
		
		function NetConnection();
		function addHeader(operation:String, mustUnderstand:Boolean=false, param:Object=null):void;
		function call(command:String, responder:Responder, ... arguments):void;
		function close():void;
		function connect(command:String, ... arguments):void;
		
		/*@Event asyncError, ioError, netStatus, securityError */
	}
	
	class NetStream extends EventDispatcher {
		const bufferLength:Number;
		const bytesLoaded:uint;
		const bytesTotal:uint;
		const currentFPS:Number;
		const liveDelay:Number;
		const objectEncoding:uint;
		const time:Number;
		
		var bufferTime:Number;
		var checkPolicyFile:Boolean;
		var client:Object;
		var soundTransform:SoundTransform;
		
		static function resetDRMVouchers():void;
		
		function NetStream(connection:NetConnection);
		function attachAudio(microphone:Microphone):void;
		function attachCamera(theCamera:Camera, snapshotMilliseconds:int=-1):void;
		function close():void;
		function pause():void;
		function play(... arguments):void;
		function publish(name:String=null, type:String=null):void;
		function receiveAudio(flag:Boolean):void;
		function receiveVideo(flag:Boolean):void;
		function receiveVideoFPS(FPS:Number):void;
		function resume():void;
		function seek(offset:Number):void;
		function send(handlerName:String, ... arguments):void;
		function setDRMAuthenticationCredentials(userName:String, password:String, type:String):void;
		function togglePause():void;
		
		/*@Event asyncError drmAuthenticate drmError drmStatus ioError netStatus onCuePoint onMetaData onPlayStatus */
	}
	
	class ObjectEncoding {
		static const AMF0:uint=0;
		static const AMF3:uint=3;
		static const DEFAULT:uint=3;
		
		static var dynamicPropertyWriter:IDynamicPropertyWriter;
	}
	
	class Responder {
		function Responder(result:Function, status:Function=null);
	}
	
	class SharedObject extends EventDispatcher {
		static var defaultObjectEncoding:uint;
		
		const data:Object;
		const size:uint;
		
		var client:Object;
		var fps:Number;
		var objectEncoding:uint;
		
		static function getLocal(name:String, localPath:String=null, secure:Boolean=false):SharedObject;
		static function getRemote(name:String, remotePath:String=null, persistence:Object=false, secure:Boolean=false):SharedObject;
		
		function clear():void;
		function close():void;
		function connect(myConnection:NetConnection, params:String=null):void;
		function flush(minDiskSpace:int=0):String;
		function send(... arguments):void;
		function setDirty(propertyName:String):void;
		function setProperty(propertyName:String, value:Object=null):void;
		
		/*@Event asyncError netStatus sync */
	}
	
	class SharedObjectFlushStatus {
		static const FLUSHED:String="flushed";
		static const PENDING:String="pending";
	}
	
	class Socket extends EventDispatcher {
		const bytesAvailable:uint;
		const connected:Boolean;
		
		var endian:String;
		var objectEncoding:uint;
		
		function Socket(host:String=null, port:int=0);
		function close():void;
		function connect(host:String, port:int):void;
		function flush():void;
		function readBoolean():Boolean;
		function readByte():int;
		function readBytes(bytes:ByteArray, offset:uint=0, length:uint=0):void;
		function readDouble():Number;
		function readFloat():Number;
		function readInt():int;
		function readMultiByte(length:uint, charSet:String):String;
		function readObject():*;
		function readShort():int;
		function readUnsignedByte():uint;
		function readUnsignedInt():uint;
		function readUnsignedShort():uint;
		function readUTF():String;
		function readUTFBytes(length:uint):String;
		function writeBoolean(value:Boolean):void;
		function writeByte(value:int):void;
		function writeBytes(bytes:ByteArray, offset:uint=0, length:uint=0):void;
		function writeDouble(value:Number):void;
		function writeFloat(value:Number):void;
		function writeInt(value:int):void;
		function writeMultiByte(value:String, charSet:String):void;
		function writeObject(object:*):void;
		function writeShort(value:int):void;
		function writeUnsignedInt(value:uint):void;
		function writeUTF(value:String):void;
		function writeUTFBytes(value:String):void;
		
		/*@Event close connect ioError securityError socketData */
	}
	
	class URLLoader extends EventDispatcher {
		var bytesLoaded:uint=0;
		var bytesTotal:uint=0;
		var data:*;
		var dataFormat:String="text";
		
		function URLLoader(request:URLRequest=null);
		function close():void;
		function load(request:URLRequest):void;
		
		/*@Event complete httpStatus ioError open progress securityError */
	}
	
	class URLLoaderDataFormat {
		static const BINARY:String="binary";
		static const TEXT:String="text";
		static const VARIABLES:String="variables";
	}
	
	class URLRequest {
		var authenticate:Boolean;
		var cacheResponse:Boolean;
		var contentType:String;
		var data:Object;
		var digest:String;
		var followRedirects:Boolean;
		var manageCookies:Boolean;
		var method:String;
		var requestHeaders:URLRequestHeader[];
		var url:String;
		var useCache:Boolean;
		var userAgent:String;
		
		function URLRequest(url:String=null);
	}
	
	class URLRequestDefaults {
		static var authenticate:Boolean;
		static var cacheResponse:Boolean;
		static var followRedirects:Boolean;
		static var manageCookies:Boolean;
		static var useCache:Boolean;
		static var userAgent:String;
		
		static function setLoginCredentialsForHost(hostname:String, user:String, password:String):*;
	}
	
	class URLRequestHeader {
		var name:String;
		var value:String;
		
		function URLRequestHeader(name:String="", value:String="");
	}
	
	class URLRequestMethod {
		static const DELETE:String="DELETE";
		static const GET:String="GET";
		static const HEAD:String="HEAD";
		static const OPTIONS:String="OPTIONS";
		static const POST:String="POST";
		static const PUT:String="PUT";
	}
	
	class URLStream extends EventDispatcher {
		const bytesAvailable:uint;
		const connected:Boolean;
		
		var endian:String;
		var objectEncoding:uint;
		
		function close():void;
		function load(request:URLRequest):void;
		function readBoolean():Boolean;
		function readByte():int;
		function readBytes(bytes:ByteArray, offset:uint=0, length:uint=0):void;
		function readDouble():Number;
		function readFloat():Number;
		function readInt():int;
		function readMultiByte(length:uint, charSet:String):String;
		function readObject():*;
		function readShort():int;
		function readUnsignedByte():uint;
		function readUnsignedInt():uint;
		function readUnsignedShort():uint;
		function readUTF():String;
		function readUTFBytes(length:uint):String;
		
		/*@Event complete httpResponseStatus httpStatus ioError open progress securityError */
	}
	
	class URLVariables {
		function URLVariables(source:String=null);
		function decode(source:String):void;
	}
	
	class XMLSocket extends EventDispatcher {
		const connected:Boolean;
		
		function XMLSocket(host:String=null, port:int=0);
		function close():void;
		function connect(host:String, port:int):void;
		function send(object:*):void;
		
		/*@Event close connect data ioError securityError */
	}
}

package window.runtime.flash.geom {
	class Matrix {
		var a:Number;
		var b:Number;
		var c:Number;
		var d:Number;
		var tx:Number;
		var ty:Number;
		
		function Matrix(a:Number=1, b:Number=0, c:Number=0, d:Number=1, tx:Number=0, ty:Number=0);
		function clone():Matrix;
		function concat(m:Matrix):void;
		function createBox(scaleX:Number, scaleY:Number, rotation:Number=0, tx:Number=0, ty:Number=0):void;
		function createGradientBox(width:Number, height:Number, rotation:Number=0, tx:Number=0, ty:Number=0):void;
		function deltaTransformPoint(point:Point):Point;
		function identity():void;
		function invert():void;
		function rotate(angle:Number):void;
		function scale(sx:Number, sy:Number):void;
		//function toString():String;
		function transformPoint(point:Point):Point;
		function translate(dx:Number, dy:Number):void;
	}
	
	class Point {
		const length:Number;
		
		var x:Number;
		var y:Number;
		
		static function distance(pt1:Point, pt2:Point):Number;
		static function interpolate(pt1:Point, pt2:Point, f:Number):Point;
		static function polar(len:Number, angle:Number):Point;
		
		function Point(x:Number=0, y:Number=0);
		function add(v:Point):Point;
		function clone():Point;
		function equals(toCompare:Point):Boolean;
		function normalize(thickness:Number):void;
		function offset(dx:Number, dy:Number):void;
		function subtract(v:Point):Point;
	}
	
	class Rectangle {
		var bottom:Number;
		var bottomRight:Point;
		var height:Number;
		var left:Number;
		var right:Number;
		var size:Point;
		var top:Number;
		var topLeft:Point;
		var width:Number;
		var x:Number;
		var y:Number;
		
		function Rectangle(x:Number=0, y:Number=0, width:Number=0, height:Number=0);
		function clone():Rectangle;
		function contains(x:Number, y:Number):Boolean;
		function containsPoint(point:Point):Boolean;
		function containsRect(rect:Rectangle):Boolean;
		function equals(toCompare:Rectangle):Boolean;
		function inflate(dx:Number, dy:Number):void;
		function inflatePoint(point:Point):void;
		function intersection(toIntersect:Rectangle):Rectangle;
		function intersects(toIntersect:Rectangle):Boolean;
		function isEmpty():Boolean;
		function offset(dx:Number, dy:Number):void;
		function offsetPoint(point:Point):void;
		function setEmpty():void;
		function union(toUnion:Rectangle):Rectangle;
	}
}

package window.runtime.flash.media {
	class ID3Info {
		var album:String;
		var artist:String;
		var comment:String;
		var genre:String;
		var songName:String;
		var track:String;
		var year:String;
	}
	
	class Microphone extends EventDispatcher {
		static const names:String[];
		
		const activityLevel:Number;
		const index:int;
		const muted:Boolean;
		const name:String;
		const silenceLevel:Number;
		const silenceTimeout:int;
		const useEchoSuppression:Boolean;
		
		var gain:Number;
		var rate:int;
		var soundTransform:SoundTransform;
		
		static function getMicrophone(index:int=0):Microphone;
		
		function setLoopBack(state:Boolean=true):void;
		function setSilenceLevel(silenceLevel:Number, timeout:int=-1):void;
		function setUseEchoSuppression(useEchoSuppression:Boolean):void;
		
		/*@Event activity, status */
	}
	
	class Sound extends EventDispatcher {
		const bytesLoaded:uint;
		const bytesTotal:int;
		const id3:ID3Info;
		const isBuffering:Boolean;
		const length:Number;
		const url:String;
		
		function Sound(stream:URLRequest=null, context:SoundLoaderContext=null);
		function close():void;
		function load(stream:URLRequest, context:SoundLoaderContext=null):void;
		function play(startTime:Number=0, loops:int=0, sndTransform:SoundTransform=null):SoundChannel;
		
		/*@Event complete, id3, ioError, open, progress */
	}
	
	class SoundChannel extends EventDispatcher {
		const leftPeak:Number;
		const position:Number;
		const rightPeak:Number;
		
		var soundTransform:SoundTransform;
		
		function stop():void;
		
		/*@Event soundComplete */
	}
	
	class SoundLoaderContext {
		var bufferTime:Number=1000;
		var checkPolicyFile:Boolean=false;
		
		function SoundLoaderContext(bufferTime:Number=1000, checkPolicyFile:Boolean=false);
	}
	
	class SoundMixer {
		static var bufferTime:int;
		static var soundTransform:SoundTransform;
		
		static function areSoundsInaccessible():Boolean;
		static function computeSpectrum(outputArray:ByteArray, FFTMode:Boolean=false, stretchFactor:int=0):void;
		static function stopAll():void;
	}
	
	class SoundTransform {
		var leftToLeft:Number;
		var leftToRight:Number;
		var pan:Number;
		var rightToLeft:Number;
		var rightToRight:Number;
		var volume:Number;
		
		function SoundTransform(vol:Number=1, panning:Number=0);
	}
}

package window.runtime.flash.security {
	class XMLSignatureValidator extends EventDispatcher {
		const digestStatus:String;
		const identityStatus:String;
		const referencesStatus:String;
		const signerCN:String;
		const signerDN:String;
		const signerExtendedKeyUsages:String[];
		const signerTrustSettings:String[];
		const validityStatus:String;
		
		var revocationCheckSetting:String;
		var uriDereferencer:URIDereferencer;
		var useSystemTrustStore:Boolean;
		
		function XMLSignatureValidator();
		function addCertificate(cert:ByteArray, trusted:Boolean):*;
		function verify(signature:XML):void;
		
		/*@Event complete error */
	}
}

package window.runtime.flash.system {
	class ApplicationDomain {
		static const currentDomain:ApplicationDomain;
		
		const parentDomain:ApplicationDomain;
		
		function ApplicationDomain(parentDomain:ApplicationDomain=null);
		function getDefinition(name:String):Object;
		function hasDefinition(name:String):Boolean;
	}
	
	class Capabilities {
		static const avHardwareDisable:Boolean;
		static const hasAccessibility:Boolean;
		static const hasAudio:Boolean;
		static const hasAudioEncoder:Boolean;
		static const hasEmbeddedVideo:Boolean;
		static const hasIME:Boolean;
		static const hasMP3:Boolean;
		static const hasPrinting:Boolean;
		static const hasScreenBroadcast:Boolean;
		static const hasScreenPlayback:Boolean;
		static const hasStreamingAudio:Boolean;
		static const hasStreamingVideo:Boolean;
		static const hasTLS:Boolean;
		static const hasVideoEncoder:Boolean;
		static const isDebugger:Boolean;
		static const language:String;
		static const localFileReadDisable:Boolean;
		static const manufacturer:String;
		static const os:String;
		static const pixelAspectRatio:Number;
		static const playerType:String;
		static const screenColor:String;
		static const screenDPI:Number;
		static const screenResolutionX:Number;
		static const screenResolutionY:Number;
		static const serverString:String;
		static const version:String;
	}
	
	class LoaderContext {
		var applicationDomain:ApplicationDomain=null;
		var checkPolicyFile:Boolean=false;
		var securityDomain:SecurityDomain=null;
		
		function LoaderContext(checkPolicyFile:Boolean=false, applicationDomain:ApplicationDomain=null, securityDomain:SecurityDomain=null);
	}
	
	class Security {
		static const APPLICATION:String="application";
		static const LOCAL_TRUSTED:String="localTrusted";
		static const LOCAL_WITH_FILE:String="localWithFile";
		static const LOCAL_WITH_NETWORK:String="localWithNetwork";
		static const REMOTE:String="remote";

		static var exactSettings:Boolean;
		static const sandboxType:String;
		
		static function allowDomain(... domains):void;
		static function allowInsecureDomain(... domains):void;
		static function loadPolicyFile(url:String):void;
		static function showSettings(panel:String="default"):void;
	}
	
	class System {
		static const ime:IME;
		static const totalMemory:uint;
		
		static var useCodePage:Boolean;
		
		function exit(code:uint):void;
		function gc():void;
		function pause():void;
		function resume():void;
		function setClipboard(string:String):void;
	}
}

package window.runtime.flash.ui {
	class Keyboard {
		static const A:uint=65;
		static const ALTERNATE:uint=18;
		static const B:uint=66;
		static const BACKQUOTE:uint=192;
		static const BACKSLASH:uint=220;
		static const BACKSPACE:uint=8;
		static const C:uint=67;
		static const CAPS_LOCK:uint=20;
		static const CharCodeStrings:Array;
		static const COMMA:uint=188;
		static const COMMAND:uint=15;
		static const CONTROL:uint=17;
		static const D:uint=68;
		static const DELETE:uint=46;
		static const DOWN:uint=40;
		static const E:uint=69;
		static const END:uint=35;
		static const ENTER:uint=13;
		static const EQUAL:uint=187;
		static const ESCAPE:uint=27;
		static const F:uint=70;
		static const F1:uint=112;
		static const F10:uint=121;
		static const F11:uint=122;
		static const F12:uint=123;
		static const F13:uint=124;
		static const F14:uint=125;
		static const F15:uint=126;
		static const F2:uint=113;
		static const F3:uint=114;
		static const F4:uint=115;
		static const F5:uint=116;
		static const F6:uint=117;
		static const F7:uint=118;
		static const F8:uint=119;
		static const F9:uint=120;
		static const G:uint=71;
		static const H:uint=72;
		static const HOME:uint=36;
		static const I:uint=73;
		static const INSERT:uint=45;
		static const J:uint=74;
		static const K:uint=75;
		static const KEYNAME_BEGIN:String="Begin";
		static const KEYNAME_BREAK:String="Break";
		static const KEYNAME_CLEARDISPLAY:String="ClrDsp";
		static const KEYNAME_CLEARLINE:String="ClrLn";
		static const KEYNAME_DELETE:String="Delete";
		static const KEYNAME_DELETECHAR:String="DelChr";
		static const KEYNAME_DELETELINE:String="DelLn";
		static const KEYNAME_DOWNARROW:String="Down";
		static const KEYNAME_END:String="End";
		static const KEYNAME_EXECUTE:String="Exec";
		static const KEYNAME_F1:String="F1";
		static const KEYNAME_F10:String="F10";
		static const KEYNAME_F11:String="F11";
		static const KEYNAME_F12:String="F12";
		static const KEYNAME_F13:String="F13";
		static const KEYNAME_F14:String="F14";
		static const KEYNAME_F15:String="F15";
		static const KEYNAME_F16:String="F16";
		static const KEYNAME_F17:String="F17";
		static const KEYNAME_F18:String="F18";
		static const KEYNAME_F19:String="F19";
		static const KEYNAME_F2:String="F2";
		static const KEYNAME_F20:String="F20";
		static const KEYNAME_F21:String="F21";
		static const KEYNAME_F22:String="F22";
		static const KEYNAME_F23:String="F23";
		static const KEYNAME_F24:String="F24";
		static const KEYNAME_F25:String="F25";
		static const KEYNAME_F26:String="F26";
		static const KEYNAME_F27:String="F27";
		static const KEYNAME_F28:String="F28";
		static const KEYNAME_F29:String="F29";
		static const KEYNAME_F3:String="F3";
		static const KEYNAME_F30:String="F30";
		static const KEYNAME_F31:String="F31";
		static const KEYNAME_F32:String="F32";
		static const KEYNAME_F33:String="F33";
		static const KEYNAME_F34:String="F34";
		static const KEYNAME_F35:String="F35";
		static const KEYNAME_F4:String="F4";
		static const KEYNAME_F5:String="F5";
		static const KEYNAME_F6:String="F6";
		static const KEYNAME_F7:String="F7";
		static const KEYNAME_F8:String="F8";
		static const KEYNAME_F9:String="F9";
		static const KEYNAME_FIND:String="Find";
		static const KEYNAME_HELP:String="Help";
		static const KEYNAME_HOME:String="Home";
		static const KEYNAME_INSERT:String="Insert";
		static const KEYNAME_INSERTCHAR:String="InsChr";
		static const KEYNAME_INSERTLINE:String="InsLn";
		static const KEYNAME_LEFTARROW:String="Left";
		static const KEYNAME_MENU:String="Menu";
		static const KEYNAME_MODESWITCH:String="ModeSw";
		static const KEYNAME_NEXT:String="Next";
		static const KEYNAME_PAGEDOWN:String="PgDn";
		static const KEYNAME_PAGEUP:String="PgUp";
		static const KEYNAME_PAUSE:String="Pause";
		static const KEYNAME_PREV:String="Prev";
		static const KEYNAME_PRINT:String="Print";
		static const KEYNAME_PRINTSCREEN:String="PrntScrn";
		static const KEYNAME_REDO:String="Redo";
		static const KEYNAME_RESET:String="Reset";
		static const KEYNAME_RIGHTARROW:String="Right";
		static const KEYNAME_SCROLLLOCK:String="ScrlLck";
		static const KEYNAME_SELECT:String="Select";
		static const KEYNAME_STOP:String="Stop";
		static const KEYNAME_SYSREQ:String="SysReq";
		static const KEYNAME_SYSTEM:String="Sys";
		static const KEYNAME_UNDO:String="Undo";
		static const KEYNAME_UPARROW:String="Up";
		static const KEYNAME_USER:String="User";
		static const L:uint=76;
		static const LEFT:uint=37;
		static const LEFTBRACKET:uint=219;
		static const M:uint=77;
		static const MINUS:uint=189;
		static const N:uint=78;
		static const NUMBER_0:uint=48;
		static const NUMBER_1:uint=49;
		static const NUMBER_2:uint=50;
		static const NUMBER_3:uint=51;
		static const NUMBER_4:uint=52;
		static const NUMBER_5:uint=53;
		static const NUMBER_6:uint=54;
		static const NUMBER_7:uint=55;
		static const NUMBER_8:uint=56;
		static const NUMBER_9:uint=57;
		static const NUMPAD:uint=21;
		static const NUMPAD_0:uint=96;
		static const NUMPAD_1:uint=97;
		static const NUMPAD_2:uint=98;
		static const NUMPAD_3:uint=99;
		static const NUMPAD_4:uint=100;
		static const NUMPAD_5:uint=101;
		static const NUMPAD_6:uint=102;
		static const NUMPAD_7:uint=103;
		static const NUMPAD_8:uint=104;
		static const NUMPAD_9:uint=105;
		static const NUMPAD_ADD:uint=107;
		static const NUMPAD_DECIMAL:uint=110;
		static const NUMPAD_DIVIDE:uint=111;
		static const NUMPAD_ENTER:uint=108;
		static const NUMPAD_MULTIPLY:uint=106;
		static const NUMPAD_SUBTRACT:uint=109;
		static const O:uint=79;
		static const P:uint=80;
		static const PAGE_DOWN:uint=34;
		static const PAGE_UP:uint=33;
		static const PERIOD:uint=190;
		static const Q:uint=81;
		static const QUOTE:uint=222;
		static const R:uint=82;
		static const RIGHT:uint=39;
		static const RIGHTBRACKET:uint=221;
		static const S:uint=83;
		static const SEMICOLON:uint=186;
		static const SHIFT:uint=16;
		static const SLASH:uint=191;
		static const SPACE:uint=32;
		static const STRING_BEGIN:String;
		static const STRING_BREAK:String;
		static const STRING_CLEARDISPLAY:String;
		static const STRING_CLEARLINE:String;
		static const STRING_DELETE:String;
		static const STRING_DELETECHAR:String;
		static const STRING_DELETELINE:String;
		static const STRING_DOWNARROW:String;
		static const STRING_END:String;
		static const STRING_EXECUTE:String;
		static const STRING_F1:String;
		static const STRING_F10:String;
		static const STRING_F11:String;
		static const STRING_F12:String;
		static const STRING_F13:String;
		static const STRING_F14:String;
		static const STRING_F15:String;
		static const STRING_F16:String;
		static const STRING_F17:String;
		static const STRING_F18:String;
		static const STRING_F19:String;
		static const STRING_F2:String;
		static const STRING_F20:String;
		static const STRING_F21:String;
		static const STRING_F22:String;
		static const STRING_F23:String;
		static const STRING_F24:String;
		static const STRING_F25:String;
		static const STRING_F26:String;
		static const STRING_F27:String;
		static const STRING_F28:String;
		static const STRING_F29:String;
		static const STRING_F3:String;
		static const STRING_F30:String;
		static const STRING_F31:String;
		static const STRING_F32:String;
		static const STRING_F33:String;
		static const STRING_F34:String;
		static const STRING_F35:String;
		static const STRING_F4:String;
		static const STRING_F5:String;
		static const STRING_F6:String;
		static const STRING_F7:String;
		static const STRING_F8:String;
		static const STRING_F9:String;
		static const STRING_FIND:String;
		static const STRING_HELP:String;
		static const STRING_HOME:String;
		static const STRING_INSERT:String;
		static const STRING_INSERTCHAR:String;
		static const STRING_INSERTLINE:String;
		static const STRING_LEFTARROW:String;
		static const STRING_MENU:String;
		static const STRING_MODESWITCH:String;
		static const STRING_NEXT:String;
		static const STRING_PAGEDOWN:String;
		static const STRING_PAGEUP:String;
		static const STRING_PAUSE:String;
		static const STRING_PREV:String;
		static const STRING_PRINT:String;
		static const STRING_PRINTSCREEN:String;
		static const STRING_REDO:String;
		static const STRING_RESET:String;
		static const STRING_RIGHTARROW:String;
		static const STRING_SCROLLLOCK:String;
		static const STRING_SELECT:String;
		static const STRING_STOP:String;
		static const STRING_SYSREQ:String;
		static const STRING_SYSTEM:String;
		static const STRING_UNDO:String;
		static const STRING_UPARROW:String;
		static const STRING_USER:String;
		static const T:uint=84;
		static const TAB:uint=9;
		static const U:uint=85;
		static const UP:uint=38;
		static const V:uint=86;
		static const W:uint=87;
		static const X:uint=88;
		static const Y:uint=89;
		static const Z:uint=90;

		static const capsLock:Boolean;
		static const numLock:Boolean;
		
		static function isAccessible():Boolean;
	}
	
	class Mouse {
		static function hide():void;
		static function show():void;
	}
}

package window.runtime.flash.utils {
	class ByteArray /*extends IDataInput, IDataOutput*/ {
		static var defaultObjectEncoding:uint;
		
		const bytesAvailable:uint;
		
		var endian:String;
		var length:uint;
		var objectEncoding:uint;
		var position:uint;
		
		function ByteArray();
		function compress(algorithm:String):void;
		function readBoolean():Boolean;
		function readByte():int;
		function readBytes(bytes:ByteArray, offset:uint=0, length:uint=0):void;
		function readDouble():Number;
		function readFloat():Number;
		function readInt():int;
		function readMultiByte(length:uint, charSet:String):String;
		function readObject():*;
		function readShort():int;
		function readUnsignedByte():uint;
		function readUnsignedInt():uint;
		function readUnsignedShort():uint;
		function readUTF():String;
		function readUTFBytes(length:uint):String;
		function uncompress(algorithm:String):void;
		function writeBoolean(value:Boolean):void;
		function writeByte(value:int):void;
		function writeBytes(bytes:ByteArray, offset:uint=0, length:uint=0):void;
		function writeDouble(value:Number):void;
		function writeFloat(value:Number):void;
		function writeInt(value:int):void;
		function writeMultiByte(value:String, charSet:String):void;
		function writeObject(object:*):void;
		function writeShort(value:int):void;
		function writeUnsignedInt(value:uint):void;
		function writeUTF(value:String):void;
		function writeUTFBytes(value:String):void;
	}
	
	class CompressionAlgorithm {
		static const DEFLATE:String="deflate";
		static const ZLIB:String="zlib";
	}
	
	class Endian {
		static const BIG_ENDIAN:String="bigEndian";
		static const LITTLE_ENDIAN:String="littleEndian";
	}
	
	class Timer extends EventDispatcher {
		const currentCount:int;
		const running:Boolean;
		
		var delay:Number;
		var repeatCount:int;
		
		function Timer(delay:Number, repeatCount:int=0);
		function reset():void;
		function start():void;
		function stop():void;
		
		/*@Event timer timerComplete */
	}
}

class Namespace {
	var prefix : String;
	var uri : String;
	
	function Namespace(uriValue:*);
	function Namespace(prefixValue:*, uriValue:*);
}

class XML {
	static var ignoreComments : Boolean;
	static var ignoreProcessingInstructions : Boolean;
	static var ignoreWhitespace : Boolean;
	static var prettyIndent : int;
	static var prettyPrinting : Boolean;

	static function defaultSettings():Object;
	static function setSettings(... rest):void;
	static function settings():Object;
	
	function XML(value:Object);
	function addNamespace(ns:Object):XML;
	function appendChild(child:Object):XML;
	function attribute(attributeName:*):XMLList;
	function attributes():XMLList;
	function child(propertyName:Object):XMLList;
	function childIndex():int;
	function children():XMLList;
	function comments():XMLList;
	function contains(value:XML):Boolean;
	function copy():XML;
	function descendants(name:Object = *):XMLList;
	function elements(name:Object = *):XMLList;
	function hasComplexContent():Boolean;
	function hasOwnProperty(p:String):Boolean;
	function hasSimpleContent():Boolean;
	function inScopeNamespaces():Namespace[];
	function insertChildAfter(child1:Object, child2:Object):*;
	function insertChildBefore(child1:Object, child2:Object):*;
	function length():int;
	function localName():Object;
	function name():Object;
	function namespace(prefix:String = null):*;
	function namespaceDeclarations():Array;
	function nodeKind():String;
	function normalize():XML;
	function parent():*;
	function prependChild(value:Object):XML;
	function processingInstructions(name:String = "*"):XMLList;
	function propertyIsEnumerable(p:String):Boolean;
	function removeNamespace(ns:Namespace):XML;
	function replace(propertyName:Object, value:XML):XML;
	function setChildren(value:Object):XML;
	function setLocalName(name:String):void;
	function setName(name:String):void;
	function setNamespace(ns:Namespace):void;
	function text():XMLList;
	function toXMLString():String;
}

class XMLList {
	function XMLList(value:Object);
	function attribute(attributeName:*):XMLList;
	function attributes():XMLList;
	function child(propertyName:Object):XMLList;
	function children():XMLList;
	function comments():XMLList;
	function contains(value:XML):Boolean;
	function copy():XMLList;
	function descendants(name:Object = *):XMLList;
	function elements(name:Object = *):XMLList;
	function hasComplexContent():Boolean;
	function hasOwnProperty(p:String):Boolean;
	function hasSimpleContent():Boolean;
	function length():int;
	function normalize():XMLList;
	function parent():Object;
	function processingInstructions(name:String = "*"):XMLList;
	function propertyIsEnumerable(p:String):Boolean;
	function text():XMLList;
	function toXMLString():String;
}

nativeWindow=new window.runtime.flash.display.NativeWindow();
htmlLoader=new window.runtime.flash.html.HTMLLoader();

air.trace=window.runtime.trace;
air.navigateToURL=window.runtime.flash.net.navigateToURL;
air.sendToURL=window.runtime.flash.net.sendToURL;

air.EncryptedLocalStore=window.runtime.flash.data.EncryptedLocalStore;
air.SQLCollationType=window.runtime.flash.data.SQLCollationType;
air.SQLColumnNameStyle=window.runtime.flash.data.SQLColumnNameStyle;
air.SQLColumnSchema=window.runtime.flash.data.SQLColumnSchema;
air.SQLConnection=window.runtime.flash.data.SQLConnection;
air.SQLError=window.runtime.flash.errors.SQLError;
air.SQLErrorEvent=window.runtime.flash.events.SQLErrorEvent;
air.SQLErrorOperation=window.runtime.flash.errors.SQLErrorOperation;
air.SQLEvent=window.runtime.flash.events.SQLEvent;
air.SQLIndexSchema=window.runtime.flash.data.SQLIndexSchema;
air.SQLMode=window.runtime.flash.data.SQLMode;
air.SQLResult=window.runtime.flash.data.SQLResult;
air.SQLSchema=window.runtime.flash.data.SQLSchema;
air.SQLSchemaResult=window.runtime.flash.data.SQLSchemaResult;
air.SQLStatement=window.runtime.flash.data.SQLStatement;
air.SQLTableSchema=window.runtime.flash.data.SQLTableSchema;
air.SQLTransactionLockType=window.runtime.flash.data.SQLTransactionLockType;
air.SQLTriggerSchema=window.runtime.flash.data.SQLTriggerSchema;
air.SQLUpdateEvent=window.runtime.flash.events.SQLUpdateEvent;
air.SQLViewSchema=window.runtime.flash.data.SQLViewSchema;

air.Clipboard=window.runtime.flash.desktop.Clipboard;
air.ClipboardFormats=window.runtime.flash.desktop.ClipboardFormats;
air.ClipboardTransferMode=window.runtime.flash.desktop.ClipboardTransferMode;
air.DockIcon=window.runtime.flash.desktop.DockIcon;
air.Icon=window.runtime.flash.desktop.Icon;
air.InteractiveIcon=window.runtime.flash.desktop.InteractiveIcon;
air.NativeApplication=window.runtime.flash.desktop.NativeApplication;
air.NativeDragActions=window.runtime.flash.desktop.NativeDragActions;
air.NativeDragManager=window.runtime.flash.desktop.NativeDragManager;
air.NativeDragOptions=window.runtime.flash.desktop.NativeDragOptions;
air.NotificationType=window.runtime.flash.desktop.NotificationType;
air.SystemTrayIcon=window.runtime.flash.desktop.SystemTrayIcon;

/*TODO
air.Bitmap=window.runtime.flash.display.Bitmap;
air.Loader =window.runtime.flash.display.Loader;
*/
air.BitmapData=window.runtime.flash.display.BitmapData;
air.NativeMenu=window.runtime.flash.display.NativeMenu;
air.NativeMenuItem=window.runtime.flash.display.NativeMenuItem;
air.NativeWindow=window.runtime.flash.display.NativeWindow;
air.NativeWindowBoundsEvent=window.runtime.flash.events.NativeWindowBoundsEvent;
air.NativeWindowDisplayState=window.runtime.flash.display.NativeWindowDisplayState;
air.NativeWindowDisplayStateEvent=window.runtime.flash.events.NativeWindowDisplayStateEvent;
air.NativeWindowInitOptions=window.runtime.flash.display.NativeWindowInitOptions;
air.NativeWindowResize=window.runtime.flash.display.NativeWindowResize;
air.NativeWindowSystemChrome=window.runtime.flash.display.NativeWindowSystemChrome;
air.NativeWindowType=window.runtime.flash.display.NativeWindowType;
air.Screen=window.runtime.flash.display.Screen;

air.ActivityEvent=window.runtime.flash.events.ActivityEvent;
air.AsyncErrorEvent=window.runtime.flash.events.AsyncErrorEvent;
air.DRMAuthenticateEvent=window.runtime.flash.events.DRMAuthenticateEvent;
air.DRMStatusEvent=window.runtime.flash.events.DRMStatusEvent;
air.DataEvent=window.runtime.flash.events.DataEvent;
air.Event=window.runtime.flash.events.Event;
air.EventDispatcher=window.runtime.flash.events.EventDispatcher;
air.FileListEvent=window.runtime.flash.events.FileListEvent;
air.HTTPStatusEvent=window.runtime.flash.events.HTTPStatusEvent;
air.IOErrorEvent=window.runtime.flash.events.IOErrorEvent;
air.InvokeEvent=window.runtime.flash.events.InvokeEvent;
air.KeyboardEvent=window.runtime.flash.events.KeyboardEvent;
air.MouseEvent=window.runtime.flash.events.MouseEvent;
air.NativeDragEvent=window.runtime.flash.events.NativeDragEvent;
air.NetStatusEvent=window.runtime.flash.events.NetStatusEvent;
air.OutputProgressEvent=window.runtime.flash.events.OutputProgressEvent;
air.ProgressEvent=window.runtime.flash.events.ProgressEvent;
air.SecurityErrorEvent=window.runtime.flash.events.SecurityErrorEvent;
air.StatusEvent=window.runtime.flash.events.StatusEvent;
air.TimerEvent=window.runtime.flash.events.TimerEvent;

air.File=window.runtime.flash.filesystem.File;
air.FileMode=window.runtime.flash.filesystem.FileMode;
air.FileStream=window.runtime.flash.filesystem.FileStream;

air.Matrix=window.runtime.flash.geom.Matrix;
air.Point=window.runtime.flash.geom.Point;
air.Rectangle=window.runtime.flash.geom.Rectangle;

air.FileFilter=window.runtime.flash.net.FileFilter;
air.LocalConnection=window.runtime.flash.net.LocalConnection;
air.NetConnection=window.runtime.flash.net.NetConnection;
air.NetStream=window.runtime.flash.net.NetStream;
air.ObjectEncoding=window.runtime.flash.net.ObjectEncoding;
air.Responder=window.runtime.flash.net.Responder;
air.SharedObject=window.runtime.flash.net.SharedObject;
air.SharedObjectFlushStatus=window.runtime.flash.net.SharedObjectFlushStatus;
air.Socket=window.runtime.flash.net.Socket;
air.URLLoader=window.runtime.flash.net.URLLoader;
air.URLLoaderDataFormat=window.runtime.flash.net.URLLoaderDataFormat;
air.URLRequest=window.runtime.flash.net.URLRequest;
air.URLRequestDefaults=window.runtime.flash.net.URLRequestDefaults;
air.URLRequestHeader=window.runtime.flash.net.URLRequestHeader;
air.URLRequestMethod=window.runtime.flash.net.URLRequestMethod;
air.URLStream=window.runtime.flash.net.URLStream;
air.URLVariables=window.runtime.flash.net.URLVariables;
air.XMLSocket=window.runtime.flash.net.XMLSocket;

/*
air.Camera=window.runtime.flash.media.Camera;
air.Video=window.runtime.flash.media.Video;
*/
air.ID3Info=window.runtime.flash.media.ID3Info;
air.Microphone=window.runtime.flash.media.Microphone;
air.Sound=window.runtime.flash.media.Sound;
air.SoundChannel=window.runtime.flash.media.SoundChannel;
air.SoundLoaderContext=window.runtime.flash.media.SoundLoaderContext;
air.SoundMixer=window.runtime.flash.media.SoundMixer;
air.SoundTransform=window.runtime.flash.media.SoundTransform;

air.ApplicationDomain=window.runtime.flash.system.ApplicationDomain;
air.Capabilities=window.runtime.flash.system.Capabilities;
air.LoaderContext=window.runtime.flash.system.LoaderContext;
air.Security=window.runtime.flash.system.Security;
air.System=window.runtime.flash.system.System;
air.Updater=window.runtime.flash.desktop.Updater;

//air.KeyEquivalent=window.runtime.flash.ui.KeyEquivalent;
air.Keyboard=window.runtime.flash.ui.Keyboard;
air.Mouse=window.runtime.flash.ui.Mouse;

air.ByteArray=window.runtime.flash.utils.ByteArray;
air.CompressionAlgorithm=window.runtime.flash.utils.CompressionAlgorithm;
air.Endian=window.runtime.flash.utils.Endian;
air.HTMLLoader=window.runtime.flash.html.HTMLLoader;
air.Timer=window.runtime.flash.utils.Timer;
air.XMLSignatureValidator=window.runtime.flash.security.XMLSignatureValidator;
